==> seedsui-react-5.6.60.tgz: package/lib/BiClock/BiClock.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
var _excluded = ["lineWidth", "size", "time", "duration", "delay", "style"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef, useRef, useImperativeHandle } from 'react';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var BiClock = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var _ref$lineWidth = _ref.lineWidth,
    lineWidth = _ref$lineWidth === void 0 ? 2 : _ref$lineWidth,
    _ref$size = _ref.size,
    size = _ref$size === void 0 ? 50 : _ref$size,
    time = _ref.time,
    _ref$duration = _ref.duration,
    duration = _ref$duration === void 0 ? 500 : _ref$duration,
    _ref$delay = _ref.delay,
    delay = _ref$delay === void 0 ? 0 : _ref$delay,
    style = _ref.style,
    others = _objectWithoutProperties(_ref, _excluded);
  var rootRef = useRef(null);
  var hourRef = useRef(null);
  var minuteRef = useRef(null);
  useImperativeHandle(ref, function () {
    return rootRef.current;
  });
  function getHourDeg(hour) {
    return hour * 30;
  }
  function getMinuteDeg(minute) {
    return minute * 6;
  }
  function aniRotate() {
    var hour = '00';
    var minute = '00';
    if (/\d{2}:\d{2}/.test(time)) {
      hour = time.split(':')[0];
      minute = time.split(':')[1];
    }
    setTimeout(function () {
      if (hourRef.current) {
        hourRef.current.style.WebkitTransitionDuration = "".concat(duration, "ms");
        hourRef.current.style.WebkitTransform = "rotate(".concat(getHourDeg(hour), "deg)");
      }
      if (minuteRef.current) {
        minuteRef.current.style.WebkitTransitionDuration = "".concat(duration, "ms");
        minuteRef.current.style.WebkitTransform = "rotate(".concat(getMinuteDeg(minute), "deg)");
      }
    }, delay);
  }
  // 动画旋转
  aniRotate();
  return /*#__PURE__*/_jsxs("div", _objectSpread(_objectSpread({}, others), {}, {
    ref: rootRef,
    className: "bi-clock".concat(others.className ? ' ' + others.className : ''),
    style: Object.assign({
      width: "".concat(size, "px"),
      height: "".concat(size, "px"),
      borderWidth: "".concat(lineWidth, "px")
    }, style || {}),
    children: [/*#__PURE__*/_jsx("div", {
      ref: hourRef,
      className: "bi-clock-hour",
      style: {
        width: "".concat(lineWidth, "px")
      }
    }), /*#__PURE__*/_jsx("div", {
      ref: minuteRef,
      className: "bi-clock-minute",
      style: {
        width: "".concat(lineWidth, "px")
      }
    }), /*#__PURE__*/_jsx("div", {
      className: "bi-clock-origin",
      style: {
        width: "".concat(lineWidth + 1, "px"),
        height: "".concat(lineWidth + 1, "px")
      }
    })]
  }));
});
export default BiClock;

==> seedsui-react-5.8.44.tgz: package/lib/BiClock/BiClock.js <==
var _excluded = ["lineWidth", "size", "time", "duration", "delay", "style"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef, useRef, useImperativeHandle } from 'react';
var BiClock = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var _ref$lineWidth = _ref.lineWidth,
    lineWidth = _ref$lineWidth === void 0 ? 2 : _ref$lineWidth,
    _ref$size = _ref.size,
    size = _ref$size === void 0 ? 50 : _ref$size,
    time = _ref.time,
    _ref$duration = _ref.duration,
    duration = _ref$duration === void 0 ? 500 : _ref$duration,
    _ref$delay = _ref.delay,
    delay = _ref$delay === void 0 ? 0 : _ref$delay,
    style = _ref.style,
    others = _objectWithoutProperties(_ref, _excluded);
  var rootRef = useRef(null);
  var hourRef = useRef(null);
  var minuteRef = useRef(null);
  useImperativeHandle(ref, function () {
    return rootRef.current;
  });
  function getHourDeg(hour) {
    return hour * 30;
  }
  function getMinuteDeg(minute) {
    return minute * 6;
  }
  function aniRotate() {
    var hour = '00';
    var minute = '00';
    if (/\d{2}:\d{2}/.test(time)) {
      hour = time.split(':')[0];
      minute = time.split(':')[1];
    }
    setTimeout(function () {
      if (hourRef.current) {
        hourRef.current.style.WebkitTransitionDuration = "".concat(duration, "ms");
        hourRef.current.style.WebkitTransform = "rotate(".concat(getHourDeg(hour), "deg)");
      }
      if (minuteRef.current) {
        minuteRef.current.style.WebkitTransitionDuration = "".concat(duration, "ms");
        minuteRef.current.style.WebkitTransform = "rotate(".concat(getMinuteDeg(minute), "deg)");
      }
    }, delay);
  }
  // 动画旋转
  aniRotate();
  return /*#__PURE__*/React.createElement("div", _extends({}, others, {
    ref: rootRef,
    className: "bi-clock".concat(others.className ? ' ' + others.className : ''),
    style: Object.assign({
      width: "".concat(size, "px"),
      height: "".concat(size, "px"),
      borderWidth: "".concat(lineWidth, "px")
    }, style || {})
  }), /*#__PURE__*/React.createElement("div", {
    ref: hourRef,
    className: "bi-clock-hour",
    style: {
      width: "".concat(lineWidth, "px")
    }
  }), /*#__PURE__*/React.createElement("div", {
    ref: minuteRef,
    className: "bi-clock-minute",
    style: {
      width: "".concat(lineWidth, "px")
    }
  }), /*#__PURE__*/React.createElement("div", {
    className: "bi-clock-origin",
    style: {
      width: "".concat(lineWidth + 1, "px"),
      height: "".concat(lineWidth + 1, "px")
    }
  }));
});
export default BiClock;
